'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = SyntaxHighlighter;

var _lowlight = require('lowlight');

var _lowlight2 = _interopRequireDefault(_lowlight);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var createTextElement = function createTextElement(text, key) {
	return _react2.default.createElement(
		'span',
		{ key: key },
		text.value
	);
};

var createClassNameString = function createClassNameString(classNames) {
	return classNames.join(" ");
};

function createChildren() {
	var childrenCount = 0;
	return function (children) {
		childrenCount += 1;
		return children.map(function (child, i) {
			return createElement(child, 'code-segement-' + childrenCount + '-' + i);
		});
	};
}
function createElement(node, key) {
	if (node.type === "text") {
		return createTextElement(node, key);
	} else if (node.tagName) {
		var TagName = node.tagName;
		var properties = node.properties;

		var childrenCreator = createChildren();
		var className = properties.className ? createClassNameString(properties.className) : "";
		var children = childrenCreator(node.children);
		return _react2.default.createElement(
			TagName,
			{ key: key, className: className },
			children
		);
	}
}

function SyntaxHighlighter(props) {
	var language = props.language;
	var children = props.children;

	var codeTree = _lowlight2.default.highlight(language, children);

	return _react2.default.createElement(
		'pre',
		props,
		codeTree.value.map(function (node, i) {
			return createElement(node, 'code-segement' + i);
		})
	);
}